'use strict';
import {Platform, NativeModules, findNodeHandle, InteractionManager} from 'react-native';
const UserXBridge = NativeModules.UserX;


class UserX {
  /**
   *	Call this method from applicationDidFinishLaunching to start UserX recording your application's session.
   *	This will start the UserX system, get the settings configurations from our server and start capturing the data according to the configuration.
   *
   *	@brief Start the UserX session
   *	@parameter apiKey The key to identify your UserX account - find it in the UserX console for your account at https://console.userx.pro/console/docs/integration
   */
  static start(apiKey) {
    UserXBridge.start(apiKey, false);
  }
    
  static startWithMarkSessionToUpload(apiKey) {
    UserXBridge.start(apiKey, true);
  }
    
  static markSessionToUpload() {
    UserXBridge.markSessionToUpload();
  }

  static configure(apiKey) {
    UserXBridge.configure(apiKey);
  }
    
  static startSession() {
    UserXBridge.startSession();
  }
    
  static stopSession() {
    UserXBridge.stopSession();
  }
    
  static addEvent(event) {
    if (!event) {
      console.log('userx : addEvent event name is invalid');
      return;
    }
    UserXBridge.addEvent(event, nil);
  }

  static addEvent(eventName, parameters) {
    if (!eventName) {
      console.log('userx : addEvent event name is invalid');
      return;
    }
    UserXBridge.addEvent(eventName, parameters);
  }
    
  static addScreenName(name) {
    UserXBridge.addScreenName(name);
  }

  static hideSensitiveView(ref) {
    if (ref == null) {
      console.log('userx : Can\'t hide a null ref (make sure the component has a ref)');
      return;
    }
    UserXBridge.hideSensitiveView(findNodeHandle(ref));
  }

  static showSensitiveView(ref) {
    if (ref == null) {
      console.log('userx : Can\'t shiow a null ref (make sure the component has a ref)');
      return;
    }
    UserXBridge.showSensitiveView(findNodeHandle(ref));
  }
	
  static showAllSensitiveViews() {
    UserXBridge.showAllSensitiveViews();
  }

  static startScreenRecording() {
    UserXBridge.startScreenRecording();
  }

  static stopScreenRecording() {
    UserXBridge.stopScreenRecording();
  }
    
  static getSessionUrl() {
    return UserXBridge.getSessionUrl();
  }
    
 static getAllSessionsUrl() {
    return UserXBridge.getAllSessionsUrl();
  }

  static getUserId() {
    return UserXBridge.getUserId();
  }

  static setUserId(userId) {
    UserXBridge.setUserId(userId);
  }
  
  static setGoogleMapView(ref, googleMapSnapshotPeriod) {
	  UserXBridge.setGoogleMapView(findNodeHandle(ref), googleMapSnapshotPeriod);
  }

  static setRecordScreenIfNotDetermined(enabled) {
    UserXBridge.setRecordScreenIfNotDetermined(enabled);
  }
}

export default UserX;
