//
//  RNUserX.m
//
//  Created by Andrey Korobkin on 17/12/2018.
//  Copyright © 2018 UserX. All rights reserved.
//

#import "RNUserX.h"

@implementation RNUserX

@synthesize bridge = _bridge;
  
RCT_EXPORT_MODULE(UserX);

RCT_EXPORT_METHOD(start: (NSString * _Nonnull) apiKey uploadIfMarked: (BOOL) enabled) {
    [UserX start: apiKey uploadIfMarked: enabled];
}

RCT_EXPORT_METHOD(markSessionToUpload) {
    [UserX markSessionToUpload];
}

RCT_EXPORT_METHOD(configure: (NSString * _Nonnull) apiKey) {
    [UserX configure: apiKey];
}
  
RCT_EXPORT_METHOD(startSession) {
    [UserX startSession];
}

RCT_EXPORT_METHOD(stopSession) {
    [UserX stopSession];
}

RCT_EXPORT_METHOD(addEvent: (NSString * _Nonnull) name withParameters: (NSDictionary<NSString *, id> * _Nullable) parameters) {
    [UserX addEvent: name with: parameters];
}

RCT_EXPORT_METHOD(addScreenName: (NSString * _Nonnull) name) {
    [UserX startScreenWithNamed: name];
}
  
RCT_EXPORT_METHOD(hideSensitiveView: (NSNumber * _Nonnull) tag) {
    dispatch_async(dispatch_get_main_queue(), ^{
        UIView* view = [self.bridge.uiManager viewForReactTag: tag];
        view.isSensitive = true;
    });
}
    
RCT_EXPORT_METHOD(showSensitiveView: (NSNumber * _Nonnull) tag) {
    dispatch_async(dispatch_get_main_queue(), ^{
        UIView* view = [self.bridge.uiManager viewForReactTag: tag];
        view.isSensitive = false;
    });
}

RCT_EXPORT_METHOD(startScreenRecording) {
    [UserX startScreenRecording];
}

RCT_EXPORT_METHOD(stopScreenRecording) {
    [UserX stopScreenRecording];
}

RCT_EXPORT_METHOD(getSessionUrl: (RCTPromiseResolveBlock) resolve rejecter: (RCTPromiseRejectBlock) reject) {
    NSString *sessionUrl = UserX.sessionUrl;

    if (sessionUrl) {
        resolve(sessionUrl);
    } else {
        NSString *code = @"session_url_unavailable";
        NSString *message = @"UserX session URL unavailable";
        NSError *error = [NSError errorWithDomain: @"RNUserX" code: 0 userInfo: nil];
        
        reject(code, message, error);
    }
}

RCT_EXPORT_METHOD(getAllSessionsUrl: (RCTPromiseResolveBlock) resolve rejecter: (RCTPromiseRejectBlock) reject) {
    NSString *sessionsUrl = UserX.externalAnalyticsUrl;

    if (sessionsUrl) {
        resolve(sessionsUrl);
    } else {
        NSString *code = @"all_sessions_url_unavailable";
        NSString *message = @"All UserX sessions URL unavailable";
        NSError *error = [NSError errorWithDomain: @"RNUserX" code: 0 userInfo: nil];
        
        reject(code, message, error);
    }
}

RCT_EXPORT_METHOD(getUserId: (RCTPromiseResolveBlock) resolve rejecter: (RCTPromiseRejectBlock) reject) {
    NSString *userId = UserX.userId;

    if (userId) {
        resolve(userId);
    } else {
        NSString *code = @"no_user_id";
        NSString *message = @"User ID is not set.";
        NSError *error = [NSError errorWithDomain: @"RNUserX" code: 0 userInfo: nil];
        
        reject(code, message, error);
    }
}

RCT_EXPORT_METHOD(setUserId: (NSString * _Nullable) value) {
    [UserX setUserId: value];
}

RCT_EXPORT_METHOD(setRecordScreenIfNotDetermined: (BOOL) value) {
    [UserX setRecordScreenIfNotDetermined: value];
}

@end
